.. currentmodule:: abjad.tools.scoretools

append_spacer_skips_to_underfull_measures_in_expr
=================================================

.. autofunction:: append_spacer_skips_to_underfull_measures_in_expr
